==> contentgrid_management_client-0.0.2.tar.gz: contentgrid_management_client-0.0.2/tests/test_console.py <==
import threading
from contentgrid_management_client import AttributeType, get_organizations
from contentgrid_hal_client import HALFormsClient
import logging
import os

TEST_CONSOLE = os.environ.get("TEST_CONSOLE", default="f") in ["t", "true", "1"]
logging.basicConfig(level=logging.DEBUG)

logging.info(f"TEST_CONSOLE = {TEST_CONSOLE}")

if TEST_CONSOLE:
    client = HALFormsClient(
        client_endpoint="http://172.17.0.1:8080",
        session_cookie="8f8ad325-7165-40d6-8bfd-4b8a6afcb595"
    )

    org = get_organizations(hal_client=client)[0]
    proj = org.get_projects()[0] 
    blueprint = proj.get_blueprints()[0]

    def test_console():
        org.get_project_by_name(proj.name)
        proj.get_blueprint_by_name(blueprint_name=blueprint.name)

        entity_definitions = blueprint.get_entity_definitions()

        test_entity_definition = entity_definitions[0]
        test_attribute_definition = test_entity_definition.attribute_definitions[0]
        # test_relation = test_entity_definition.relation_definitions[0]

        test_entity_definition.get_blueprint()
        test_attribute_definition.get_blueprint()
        # test_relation.get_blueprint()
        # test_relation.get_source_entity_definition()
        # test_relation.get_target_entity_definition()
        
        automation = blueprint.create_automation("test", "ml", {"test": "barz"})

        automations = blueprint.get_automations()

        automation = automations[0]
        logging.info(blueprint.get_entity_definition_by_name(entity_definitions[0].name).attribute_definitions)

        logging.info(blueprint.get_automations())

        # logging.info(automation._create_automation_annotation({"test": "yoo"}))
        annotation = automation.create_annotation_on_entity(entity_definitions[0].name, {"test": "yoyo"})
        logging.info(annotation)

        logging.info(annotation.subject.type)

        logging.info(automation.create_annotation_on_attribute(entity_name=entity_definitions[0].name, attribute_name=entity_definitions[0].attribute_definitions[0].name, data= {"test": "yoyo"}).subject.type)

        automation.put_data(data={"name" :"test", "data" : {"foo" : "bar"}})

    def test_create_entity():
        entity = blueprint.create_entity(entity_name="testcreateentitiy", entity_description="description")
        assert entity.description == "description"
        entity.patch(new_entity_description="new description")
        assert entity.description == "new description"
        entity.delete()


    def test_create_relation():
        try:
            entity = blueprint.create_entity("testaddrelation", entity_description="description")
        except:
            entity = blueprint.get_entity_definition_by_name("testaddrelation")
        entity.create_relation("testrelation", "testaddrelation", many_target_per_source=False, many_source_per_target=False, relation_description="description")
        relation = entity.get_relation_definition_by_name("testrelation")
        assert relation.description == "description"
        relation.patch(new_relation_description="new description")
        assert relation.description == "new description"
        entity.delete()

    def test_create_attribute():
        try:
            entity = blueprint.create_entity("testaddattribute", entity_description="description")
        except:
            entity = blueprint.get_entity_definition_by_name("testaddattribute")
        entity.create_attribute("testattribute", AttributeType.STRING, required=True, attribute_description="test attribute description")
        attribute = entity.get_attribute_definition_by_name("testattribute")
        assert attribute.description == "test attribute description"
        attribute.patch(attribute_description="new description")
        assert attribute.description == "new description"
        entity.delete()

    def test_concurrent():
        threads = []
        for i in range(100):
            thread = threading.Thread(target=blueprint.get_project)
            threads.append(thread)
            thread.start()
        
        for thread in threads:
            thread.join()

==> contentgrid_management_client-0.0.4.tar.gz: contentgrid_management_client-0.0.4/tests/test_console.py <==
import threading
from contentgrid_management_client import AttributeType, get_organizations
from contentgrid_management_client.console import AllowedValuesAttributeConstraint, ConstraintType
from contentgrid_hal_client import HALFormsClient
import logging
import os

TEST_CONSOLE = os.environ.get("TEST_CONSOLE", default="f") in ["t", "true", "1"]
logging.basicConfig(level=logging.DEBUG)

logging.info(f"TEST_CONSOLE = {TEST_CONSOLE}")

if TEST_CONSOLE:
    client = HALFormsClient(
        client_endpoint="http://172.17.0.1:8080",
        session_cookie="121fc225-191e-4f49-9792-5815fab47d63"
    )

    org = get_organizations(hal_client=client)[0]
    proj = org.get_projects()[0] 
    blueprint = proj.get_blueprints()[0]

    def test_console():
        org.get_project_by_name(proj.name)
        proj.get_blueprint_by_name(blueprint_name=blueprint.name)

        entity_definitions = blueprint.get_entity_definitions()

        test_entity_definition = entity_definitions[0]
        test_attribute_definition = test_entity_definition.attribute_definitions[0]
        # test_relation = test_entity_definition.relation_definitions[0]

        test_entity_definition.get_blueprint()
        test_attribute_definition.get_blueprint()
        # test_relation.get_blueprint()
        # test_relation.get_source_entity_definition()
        # test_relation.get_target_entity_definition()
        
        automation = blueprint.create_automation("test", "ml", {"test": "barz"})

        automations = blueprint.get_automations()

        automation = automations[0]
        logging.info(blueprint.get_entity_definition_by_name(entity_definitions[0].name).attribute_definitions)

        logging.info(blueprint.get_automations())

        # logging.info(automation._create_automation_annotation({"test": "yoo"}))
        annotation = automation.create_annotation_on_entity(entity_definitions[0].name, {"test": "yoyo"})
        logging.info(annotation)

        logging.info(annotation.subject.type)

        logging.info(automation.create_annotation_on_attribute(entity_name=entity_definitions[0].name, attribute_name=entity_definitions[0].attribute_definitions[0].name, data= {"test": "yoyo"}).subject.type)

        automation.put_data(data={"name" :"test", "data" : {"foo" : "bar"}})

    def test_create_entity():
        entity = blueprint.create_entity(entity_name="testcreateentitiy", entity_description="description")
        assert entity.description == "description"
        entity.patch(new_entity_description="new description")
        assert entity.description == "new description"
        entity.delete()


    def test_create_relation():
        try:
            entity = blueprint.create_entity("testaddrelation", entity_description="description")
        except:
            entity = blueprint.get_entity_definition_by_name("testaddrelation")
        entity.create_relation("testrelation", "testaddrelation", many_target_per_source=False, many_source_per_target=False, relation_description="description")
        relation = entity.get_relation_definition_by_name("testrelation")
        assert relation.description == "description"
        relation.patch(new_relation_description="new description")
        assert relation.description == "new description"
        entity.delete()

    def test_create_attribute():
        try:
            entity = blueprint.create_entity("testaddattribute", entity_description="description")
        except:
            entity = blueprint.get_entity_definition_by_name("testaddattribute")
        entity.create_attribute("testattribute", AttributeType.STRING, required=True, attribute_description="test attribute description")
        attribute = entity.get_attribute_definition_by_name("testattribute")
        assert attribute.description == "test attribute description"
        attribute.patch(attribute_description="new description")
        assert attribute.description == "new description"
        entity.delete()

    def test_concurrent():
        threads = []
        for i in range(100):
            thread = threading.Thread(target=blueprint.get_project)
            threads.append(thread)
            thread.start()
        
        for thread in threads:
            thread.join()

    def test_get_constraints():
        attribute = blueprint.get_entity_definitions()[0].attribute_definitions[0]
        assert len(attribute.get_constraints()) == 0
    
    def test_create_constraints():
        try:
            entity = blueprint.create_entity("contrained-entity", entity_description="description")
        except:
            entity = blueprint.get_entity_definition_by_name("contrained-entity")
        
        try:
            attribute = entity.create_attribute("allowed_values_attr", AttributeType.STRING)
            constraints = attribute.get_constraints()
            assert len(constraints) == 0
        except:
            attribute = entity.get_attribute_definition_by_name("allowed_values_attr")

        attribute.add_allowed_values_constraint(["a","b","c"])
        constraints = attribute.get_constraints()
        assert len(constraints) == 1
        constraint = attribute.get_constraints_of_type(ConstraintType.ALLOWED_VALUES)[0]
        assert constraint.values == ["a", "b", "c"]
        assert constraint.type == ConstraintType.ALLOWED_VALUES
        assert type(constraint) == AllowedValuesAttributeConstraint
